@@ -6,6 +6,7 @@
 #include "dbuslogin1manager.h"
 #include "deepinauthframework.h"
 #include "sessionbasemodel.h"
+#include "greeter_display_wayland.h"
 
 #include <QLightDM/Greeter>
 #include <QLightDM/SessionsModel>
@@ -36,6 +37,7 @@ signals:
     void requestUpdateBackground(const QString &path);
     void requestShowPrompt(const QString &prompt);
     void requestShowMessage(const QString &message);
+    void showLoginWindow(bool isShow);
 
 public slots:
     /* New authentication framework */
@@ -53,6 +55,7 @@ private slots:
     void onAuthStateChanged(const int type, const int state, const QString &message);
     void onReceiptChanged(bool state);
     void onCurrentUserChanged(const std::shared_ptr<User> &user);
+    void onSessionCreated();
 
 private:
     void initConnections();
@@ -71,12 +74,16 @@ private:
     void recoveryUserKBState(std::shared_ptr<User> user);
     void startGreeterAuth(const QString &account = QString());
     void changePasswd();
+    void screenSwitchByWldpms(bool active);
 
 private:
     QLightDM::Greeter *m_greeter;
     DeepinAuthFramework *m_authFramework;
     DBusLockService *m_lockInter;
     SoundThemePlayerInter *m_soundPlayerInter;
+#ifdef USE_DEEPIN_WAYLAND
+    GreeterDisplayWayland *m_greeterDisplayWayland;
+#endif
     QTimer *m_resetSessionTimer;
     QTimer *m_limitsUpdateTimer;
     QString m_account;
