@@ -46,9 +46,9 @@ AuthModule::AuthModule(const AuthCommon::AuthType type, QWidget *parent)
     , m_limitsInfo(new LimitsInfo())
     , m_aniTimer(new QTimer(this))
     , m_unlockTimer(new QTimer(this))
-    , m_showAuthState(true)
     , m_isAuthing(false)
     , m_authFactorType(DDESESSIONCC::SingleAuthFactor)
+    , m_showAuthState(false)
 {
     setMinimumHeight(37);
 
@@ -135,15 +135,11 @@ void AuthModule::setLimitsInfo(const LimitsInfo &info)
     updateUnlockTime();
 }
 
-void AuthModule::setShowAuthState(bool showAuthState)
-{
-    m_showAuthState = showAuthState;
-}
-
 void AuthModule::setAuthStatueVisible(bool visible)
 {
-    if (m_authStateLabel)
+    if (m_authStateLabel) {
         m_authStateLabel->setVisible(visible);
+    }
 }
 
 /**
