@@ -24,6 +24,7 @@
 
 #include "auth_widget.h"
 #include "userinfo.h"
+#include "authcommon.h"
 
 #include <DArrowRectangle>
 #include <DBlurEffectWidget>
@@ -49,6 +50,7 @@ class SFAWidget : public AuthWidget
 
 public:
     explicit SFAWidget(QWidget *parent = nullptr);
+    ~SFAWidget();
 
     void setModel(const SessionBaseModel *model) override;
     void setAuthType(const int type) override;
@@ -57,11 +59,15 @@ public:
 
 public slots:
     void onRetryButtonVisibleChanged(bool visible);
+    void onRequestChangeAuth(const int authType);
 
 protected:
     void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
     void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
 
+protected Q_SLOTS:
+    void updateBlurEffectGeometry();
+
 private:
     void initUI();
     void initConnections();
@@ -81,6 +87,7 @@ private:
     void setBioAuthStateVisible(AuthModule *authModule, bool visible);
     void updateSpaceItem();
     void updateFocus();
+    void initAccount();
 
 private:
     QVBoxLayout *m_mainLayout;
@@ -93,6 +100,9 @@ private:
     QSpacerItem *m_bioAuthStatePlaceHolder;
     QSpacerItem *m_bioBottomSpacingHolder;
     QSpacerItem *m_authTypeBottomSpacingHolder;
+    AuthCommon::AuthType m_currentAuthType;
+    static QList<SFAWidget*> SFAWidgetObjs;
+    bool m_inited;
 };
 
 #endif // SFAWIDGET_H
