@@ -312,8 +312,7 @@ void ShutdownWidget::initUI()
     m_actionLayout->addStretch();
 
     if (findValueByQSettings<bool>(DDESESSIONCC::session_ui_configs, "Shutdown", "enableSystemMonitor", true)) {
-        QFile file("/usr/bin/deepin-system-monitor");
-        if (file.exists()) {
+        if (!QStandardPaths::findExecutable("deepin-system-monitor").isEmpty()) {
             m_systemMonitor = new SystemMonitor;
             m_systemMonitor->setAccessibleName("SystemMonitor");
             m_systemMonitor->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -422,7 +421,15 @@ void ShutdownWidget::onStatusChanged(SessionBaseModel::ModeStatus status)
         roundItemButton = m_requireShutdownButton;
     }
 
-    int index = m_btnList.indexOf(roundItemButton);
+    // 同步显示另一个显示器关机界面上当前选中的按钮，若还未同步则显示关机或锁屏默认按钮
+    if (m_index >= 0 && m_index < m_btnList.size()) {
+        RoundItemButton * tmpBtn = m_btnList.at(m_index);
+        if (tmpBtn && tmpBtn->isVisible()) {
+            roundItemButton = tmpBtn;
+        }
+    }
+
+    int index =  m_btnList.indexOf(roundItemButton);
     roundItemButton->updateState(RoundItemButton::Checked);
     m_frameDataBind->updateValue("ShutdownWidget", index);
 
@@ -433,7 +440,7 @@ void ShutdownWidget::onStatusChanged(SessionBaseModel::ModeStatus status)
 
 void ShutdownWidget::runSystemMonitor()
 {
-    QProcess::startDetached("/usr/bin/deepin-system-monitor");
+    QProcess::startDetached("deepin-system-monitor", {});
 
     if (m_systemMonitor) {
         m_systemMonitor->clearFocus();
@@ -547,12 +554,15 @@ bool ShutdownWidget::event(QEvent *e)
     }
 
     if (e->type() == QEvent::FocusIn) {
-        if (m_index < 0) {
+        if (m_index < 0 || m_index >= m_btnList.size()) {
             m_index = 0;
         }
         m_frameDataBind->updateValue("ShutdownWidget", m_index);
         m_btnList.at(m_index)->updateState(RoundItemButton::Checked);
     } else if (e->type() == QEvent::FocusOut) {
+        if (m_index < 0 || m_index >= m_btnList.size()) {
+            m_index = 0;
+        }
         m_btnList.at(m_index)->updateState(RoundItemButton::Normal);
     }
 
@@ -565,6 +575,12 @@ void ShutdownWidget::showEvent(QShowEvent *event)
     QFrame::showEvent(event);
 }
 
+void ShutdownWidget::hideEvent(QHideEvent *event)
+{
+    m_index = -1;
+    QFrame::hideEvent(event);
+}
+
 void ShutdownWidget::updateLocale(std::shared_ptr<User> user)
 {
     Q_UNUSED(user)
