@@ -25,9 +25,9 @@
         <source>Face ID locked, use password please</source>
         <translation>Face ID e kyçur, ju lutemi, përdorni fjalëkalim</translation>
     </message>
-    <message numerus="yes">
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
+    <message>
+        <source>Device unavailable!</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -52,14 +52,6 @@
         <source>Fingerprint locked, use password please</source>
         <translation>Shenja gishti të kyçura, ju lutemi, përdorni fjalëkalim</translation>
     </message>
-    <message numerus="yes">
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
-    </message>
-    <message>
-        <source>Please try again 1 minute later</source>
-        <translation>Ju lutemi, riprovoni pas 1 minute</translation>
-    </message>
 </context>
 <context>
     <name>AuthIris</name>
@@ -87,10 +79,6 @@
         <source>Iris ID locked, use password please</source>
         <translation>Iris ID e kyçur, ju lutemi, përdorni fjalëkalimin</translation>
     </message>
-    <message numerus="yes">
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
-    </message>
 </context>
 <context>
     <name>AuthPassword</name>
@@ -114,10 +102,6 @@
         <source>Password</source>
         <translation>Fjalëkalim</translation>
     </message>
-    <message numerus="yes">
-        <source>Please try again %n minute(s) later</source>
-        <translation><numerusform>Ju lutemi, riprovoni pas %n minute</numerusform><numerusform>Ju lutemi, riprovoni pas %n minutash</numerusform></translation>
-    </message>
     <message>
         <source>Please try again 1 minute later</source>
         <translation>Ju lutemi, riprovoni pas 1 minute</translation>
@@ -212,11 +196,11 @@
     <name>GreeterWorker</name>
     <message>
         <source>Wrong account</source>
-        <translation type="unfinished"/>
+        <translation>Llogari e gabuar</translation>
     </message>
     <message>
         <source>Wrong Password</source>
-        <translation type="unfinished"/>
+        <translation>Fjalëkalim i Gabuar</translation>
     </message>
 </context>
 <context>
@@ -267,7 +251,7 @@
     <name>SessionWidget</name>
     <message>
         <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
-        <translation type="unfinished"/>
+        <translation>Keni aktivizuar shkallën e lartë të sigurisë së sistemit, ndaj s’mund të kalohet nën mënyrën Wayland, ju lutemi, çaktivizoni shkallën e lartë të sigurisë së sistemit që nga Qendra e Sigurisë dhe riprovoni.</translation>
     </message>
 </context>
 <context>
